# georgescalc

Um misto de funções matemáticas.
 ### georgescalc.equations
O módulo georges-calc.equations contém:
* A função bhaskara(a,b,c): Que retorna o valor de X se houver raízes reais e None, se não houver;
* A função delta(a,b,c), que retorna o valor de delta. 

### georgescalc.functions
O módulo georges-calc.functions contém:
* A função fibonacci(n_termos), que retorna uma lista de termos da sequência de Fibonacci. 
	
### georgescalc.total
O módulo georges-calc.functions contém:
* A função total_sum(num), que retorna a soma dos números fornecidos como parâmetro.
* A função total_product(num), que retorna o produto dos números fornecidos como parâmetro. 

## Instalação

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install georges_calc

```bash
pip install georgescalc
```

## Usage

```python
from georgescalc import functions
functions.fibonacci(7)
```

## Author
George Pontes da Cunha

## License
[MIT](https://choosealicense.com/licenses/mit/)

